@@ -1,6 +1,9 @@
 #include "cache.h"
 
-static const char prune_packed_usage[] = "git-prune-packed (no arguments)";
+static const char prune_packed_usage[] =
+"git-prune-packed [-n]";
+
+static int dryrun;
 
 static void prune_dir(int i, DIR *dir, char *pathname, int len)
 {
@@ -18,7 +21,9 @@ static void prune_dir(int i, DIR *dir, char *pathname, int len)
 		if (!has_sha1_pack(sha1))
 			continue;
 		memcpy(pathname + len, de->d_name, 38);
-		if (unlink(pathname) < 0)
+		if (dryrun)
+			printf("rm -f %s\n", pathname);
+		else if (unlink(pathname) < 0)
 			error("unable to unlink %s", pathname);
 	}
 }
@@ -55,8 +60,11 @@ int main(int argc, char **argv)
 		const char *arg = argv[i];
 
 		if (*arg == '-') {
-			/* Handle flags here .. */
-			usage(prune_packed_usage);
+			if (!strcmp(arg, "-n"))
+				dryrun = 1;
+			else
+				usage(prune_packed_usage);
+			continue;
 		}
 		/* Handle arguments here .. */
 		usage(prune_packed_usage);
